/*++

Copyright (c) 1996  Oregon Micro Systems

Module Name:

    Testdrv.c

Abstract:

    A simple Win32 app that tests the OMS motor controller driver 1

Environment:

    user mode only


Revision History:

    06-11-96 : created
--*/



#include <windows.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <winioctl.h>

//Define the OMS NT I/O control codes
#include "ntioctl.h"                                               


VOID
__cdecl
main(
    IN int   argc,
    IN char *argv[]
    )
/*++

Routine Description:

Arguments:

Return Value:

--*/
{
    char     completeDeviceName[64] = "\\\\.\\OMS0";
    HANDLE   hDevice;
    BOOLEAN  Status;
    char     WyCommand[128] = "wy";
    char     Command2[128] = "aa rp";
    char     Command3[128] = "aa mr1000,1000,1000,1000;gd id";
    char     Command4[128] = "zz;";
    char     ResponseString[128];
    DWORD    BytesReturned;
    UCHAR    DoneFlags;
    UCHAR    DoneMask;
    UCHAR    StatusFlags;
    UCHAR    StatusMask;
    UCHAR    CommandCharsSent;
    int      Fields;
    int      Controller;
    int      i;
    BOOLEAN ResetOk;
    
    if(argc != 2)
    {
      printf("usage: testdrv <controller Id number>\n");
      exit (1);
    }  

    //Get the motor controller number from the command line
    Fields = sscanf(argv[1], "%d",&Controller);
    if((Controller >= 0) && (Controller <=9))
    {
       //Include controller id number in the device name
       completeDeviceName[7] += (UCHAR)Controller;
    }   
    else
    {
       printf("Valid controller Id numbers are between 0 and 9\n");
       exit(1);
    }

    //Open the motor controller device OMS...
    hDevice = CreateFile (completeDeviceName,
                          GENERIC_READ | GENERIC_WRITE,
                          0,
                          NULL,
                          OPEN_EXISTING,
                          FILE_ATTRIBUTE_NORMAL,
                          NULL
                          );

    if (hDevice == ((HANDLE)-1))
    {
        printf ("Can't get a handle to %s\n",
                completeDeviceName
                );
        exit(1);        
    }
    else
    {
        printf ("CreateFile SUCCESS\n");
    }

    //Get the driver's version
    Status = DeviceIoControl(
                             hDevice,               //CreateFile Device handle
                             (DWORD)IOCTL_OMS_GET_VERSION,
                             (LPVOID)NULL,        //No Command string to send
                             (DWORD)0,            
                             (LPVOID)ResponseString,//Controller response here
                             (DWORD)128,            //Maximum length response
                             &BytesReturned,        //Actual length of response
                                                    //including the null.
                              NULL);                //Synchronous Operations 
    if(ResponseString[0] != (UCHAR)NULL)
    {
      printf("Driver Version = %s \n", ResponseString);
    }
    

    //Get the current position of all axes
    //Send the command string "AA RP" to oms1 and wait for the response
    Status = DeviceIoControl(
                             hDevice,               //CreateFile Device handle
                             (DWORD)IOCTL_OMS_QUERY,//Send command get response
                             (LPVOID)Command2,      //Command string to send
                             (DWORD)128,            //Maximum length of command
                             (LPVOID)ResponseString,//Controller response here
                             (DWORD)128,            //Maximum length response
                             &BytesReturned,        //Actual length of response
                                                    //including the null.
                              NULL);                //Synchronous Operations 
    if(ResponseString[0] != (UCHAR)NULL)
    {
      printf("Current axis positions = %s \n", ResponseString);
    }
    else
    {
      printf("*** Response time out \n");
      CloseHandle (hDevice);
      exit(1);
    }   
      
                              
    //Clear all done flags for x,y,z,t                          
    DoneMask = 0xff;
    Status = DeviceIoControl(
                             hDevice,
                             (DWORD)IOCTL_OMS_CLR_DONE, //Clear selected done flags
                             &DoneMask,                 //Flags selected by ones
                             (DWORD) 1,                 //Mask is one byte
                             (LPVOID)NULL,              //No response expected
                             (DWORD) 0,                 //...
                             &BytesReturned,            //Not used but required
                              NULL);                    //Synchronous Operations
    Status = DeviceIoControl(
                             hDevice,
                             (DWORD)IOCTL_OMS_READ_DONE,//Read the driver's 
                                                        //copy of the done flags
                             (LPVOID)NULL,              //Command string 
                             (DWORD) 0,                 //not sent
                             &DoneFlags,                //Done flags go here
                             (DWORD)1,                  //Flags require one byte
                             &BytesReturned,            //Bytes returned
                              NULL);                    //Synchronous Operations
    printf("Done status before = %0x \n", DoneFlags);
                              
    //Send a move command:
    // mr1000,1000,1000,1000,1000;gd id                          
    //don't expect a response
    Status = DeviceIoControl(
                             hDevice,
                             (DWORD)IOCTL_OMS_COMMAND, //Send commmand string
                                                       //don't expect a response
                             (LPVOID)Command3,         //Command string
                             (DWORD)128,               //Max length of string
                             &CommandCharsSent,        //Returns count
                             (DWORD)1,                 //of chars sent...   
                              &BytesReturned,          //No used but required
                              NULL);                   //Synchronous Operations
                              
    //Check to make sure the controller accepted all of the command string
    if(CommandCharsSent != strlen(Command3))
    {
       printf("OMS controller is hung or busy\n");
       CloseHandle (hDevice);
       exit(1);
    }   
                              
    //Wait until the move is complete
    DoneFlags = 0;
    while ((DoneFlags & 0x0f) != 0x0f)
    {                          
      Status = DeviceIoControl(
                             hDevice,
                             (DWORD)IOCTL_OMS_READ_DONE,//Read the driver's 
                                                        //copy of the done flags
                             (LPVOID)NULL,              //Command string 
                             (DWORD) 0,                 //not sent
                             &DoneFlags,                //Done flags go here
                             (DWORD)1,                  //Flags require one byte
                             &BytesReturned,            //Bytes returned
                              NULL);                    //Synchronous Operations
    }                          
    printf("Done status after = %0x \n", DoneFlags);
    //Get the current position of all axes
    //Send the command string "AA RP" to oms1 and wait for the response
    Status = DeviceIoControl(
                             hDevice,               //CreateFile Device handle
                             (DWORD)IOCTL_OMS_QUERY,//Send command get response
                             (LPVOID)Command2,      //Command string to send
                             (DWORD)128,            //Maximum length of command
                             (LPVOID)ResponseString,//Controller response here
                             (DWORD)128,            //Maximum length response
                             &BytesReturned,        //Actual length of response
                                                    //including the null.
                              NULL);                //Synchronous Operations 
                              
    if(ResponseString[0] != (UCHAR)NULL)
    {
      printf("New axis positions = %s \n", ResponseString);
    }
    else
    {
      printf("*** Response time out \n");
      CloseHandle (hDevice);
      exit(1);
    }   
                              
    
    //Clear clear bits 1, 3 in the drivers copy of the done flags                          
    DoneMask = 0x0a;
    Status = DeviceIoControl(
                             hDevice,
                             (DWORD)IOCTL_OMS_CLR_DONE, //Clear selected done flags
                             &DoneMask,                 //Flags selected by ones
                             (DWORD) 1,                 //Mask is one byte
                             (LPVOID)NULL,              //No response expected
                             (DWORD) 0,                 //...
                             &BytesReturned,            //Not used but required
                              NULL);                    //Synchronous Operations
                              
    //Query done status                          
    Status = DeviceIoControl(
                             hDevice,
                             (DWORD)IOCTL_OMS_READ_DONE,//Read the driver's 
                                                        //copy of the done flags
                             (LPVOID)NULL,              //Command string 
                             (DWORD) 0,                 //not sent
                             &DoneFlags,                //Done flags go here
                             (DWORD)1,                  //Flags require one byte
                             &BytesReturned,            //Bytes returned
                              NULL);                    //Synchronous Operations
    printf("Done status after clear = %0x \n", DoneFlags);
    
    //Clear bits 0, 2 in the drivers copy of the done flags                          
    DoneMask = 0x05;
    Status = DeviceIoControl(
                             hDevice,
                             (DWORD)IOCTL_OMS_CLR_DONE,
                             &DoneMask,
                             (DWORD) 1,
                             (LPVOID)NULL,
                             (DWORD) 0,
                             &BytesReturned,
                              NULL);
    
    //Query done status                          
    Status = DeviceIoControl(
                             hDevice,
                             (DWORD)IOCTL_OMS_READ_DONE,//Read the driver's 
                                                        //copy of the done flags
                             (LPVOID)NULL,              //Command string 
                             (DWORD) 0,                 //not sent
                             &DoneFlags,                //Done flags go here
                             (DWORD)1,                  //Flags require one byte
                             &BytesReturned,            //Bytes returned
                              NULL);                    //Synchronous Operations
    printf("Done status = %0x \n", DoneFlags);
                              
    //Query status before command error                         
    Status = DeviceIoControl(
                             hDevice,
                             (DWORD)IOCTL_OMS_READ_STATUS, //Read status flags
                             (LPVOID)NULL,                 //String not sent
                             (DWORD) 0,                    //...
                             &StatusFlags,                 //Status flags go here
                             (DWORD)1,                     //Return one byte
                             &BytesReturned,               //Actual bytes returned
                              NULL);                       //Synchronous operations
    printf("Error status = %0x \n", StatusFlags);
                              
    //Force a command error and a response time out
    Status = DeviceIoControl(
                             hDevice,
                             (DWORD)IOCTL_OMS_QUERY,
                             (LPVOID)Command4,
                             (DWORD)128,            //Maximum length of command
                             (LPVOID)ResponseString,//Controller response here
                             (DWORD)128,            //Maximum length response
                              &BytesReturned,
                              NULL);
    printf("Null Response = %s \n", ResponseString);
                              
    //Query status following command error                          
    Status = DeviceIoControl(
                             hDevice,
                             (DWORD)IOCTL_OMS_READ_STATUS, //Read status flags
                             (LPVOID)NULL,                 //String not sent
                             (DWORD) 0,                    //...
                             &StatusFlags,                 //Status flags go here
                             (DWORD)1,                     //Return one byte
                             &BytesReturned,               //Actual bytes returned
                              NULL);                       //Synchronous operations
    printf("Error status = %0x \n", StatusFlags);
    
    //Clear all bits in the drivers copy of the error/status flags                          
    StatusMask = 0xff;
    Status = DeviceIoControl(
                             hDevice,
                             (DWORD)IOCTL_OMS_CLR_STATUS,
                             &StatusMask,
                             (DWORD) 1,
                             (LPVOID)NULL,
                             (DWORD) 0,
                             &BytesReturned,
                              NULL);
                              
    //Query status after clear
    Status = DeviceIoControl(
                             hDevice,
                             (DWORD)IOCTL_OMS_READ_STATUS, //Read status flags
                             (LPVOID)NULL,                 //String not sent
                             (DWORD) 0,                    //...
                             &StatusFlags,                 //Status flags go here
                             (DWORD)1,                     //Return one byte
                             &BytesReturned,               //Actual bytes returned
                              NULL);                       //Synchronous operations
    printf("Error status = %0x \n", StatusFlags);
    
    //send "wy" command                          
    Status = DeviceIoControl(
                             hDevice,               //CreateFile Device handle
                             (DWORD)IOCTL_OMS_QUERY,//Send command get response
                             (LPVOID)WyCommand,     //Command string to send
                             (DWORD)128,            //Maximum length of command
                             (LPVOID)ResponseString,//Controller response here
                             (DWORD)128,            //Maximum length response
                             &BytesReturned,        //Actual length of response
                                                    //including the null.
                              NULL);                //Synchronous Operations 
    if(ResponseString[0] != (UCHAR)NULL)
    {
      printf("WY Response = %s \n", ResponseString);
    }
    else
    {
      printf("*** Response time out \n");
      CloseHandle (hDevice);
      exit(1);
    }   
    

   //Set X axis position to zero
    Status = DeviceIoControl(
                             hDevice,
                             (DWORD)IOCTL_OMS_COMMAND, //Send commmand string
                                                       //don't expect a response
                             "ax lp0;",                //Command string
                             (DWORD)128,               //Max length of string
                             &CommandCharsSent,  //Returns count
                             (DWORD)1,                  //...
                             &BytesReturned,          
                              NULL);                   //Synchronous Operations

    if(CommandCharsSent != 7)
    {
      printf("ax lp0 timed out\n");
      CloseHandle (hDevice);
      exit(1);
    }   
                                
    //Set y axis position to zero
    Status = DeviceIoControl(
                             hDevice,
                             (DWORD)IOCTL_OMS_COMMAND, //Send commmand string
                                                       //don't expect a response
                             "ay lp0;",                //Command string
                             (DWORD)128,               //Max length of string
                             &CommandCharsSent,  //Returns count
                             (DWORD)1,                  //...
                             &BytesReturned,          
                              NULL);                   //Synchronous Operations
                              
    if(CommandCharsSent != 7)
    {
      printf("ay lp0 timed out\n");
      CloseHandle (hDevice);
      exit(1);
    }  
                              
    //Get the current position of all axes
    //Send the command string "AA RP" to oms1 and wait for the response
    Status = DeviceIoControl(
                             hDevice,               //CreateFile Device handle
                             (DWORD)IOCTL_OMS_QUERY,//Send command get response
                             "am rp;",              //Command string to send
                             (DWORD)128,            //Maximum length of command
                             (LPVOID)ResponseString,//Controller response here
                             (DWORD)128,            //Maximum length response
                             &BytesReturned,        //Actual length of response
                                                    //including the null.
                              NULL);                //Synchronous Operations 
                              
    if(ResponseString[0] != (UCHAR)NULL)
    {
      printf("0 - Axes positions = %s \n", ResponseString);
    }
    else
    {
      printf("*** Response time out \n");
      Status = DeviceIoControl(
                               hDevice,
                               (DWORD)IOCTL_OMS_READ_STATUS,//Read the driver's 
                                                          //copy of the status flags
                               (LPVOID)NULL,              //Command string 
                               (DWORD) 0,                 //not sent
                               &StatusFlags,              //Status flags go here
                               (DWORD)1,                  //Flags require one byte
                               &BytesReturned,            //Bytes returned
                                NULL);                    //Synchronous Operations
      //Make sure the driver's copy of status flags are clear                          
    //Clear all bits in the drivers copy of the error/status flags                          
    StatusMask = 0xff;
    Status = DeviceIoControl(
                               hDevice,
                               (DWORD)IOCTL_OMS_CLR_STATUS,
                              &StatusMask,
                               (DWORD) 1,                 //Mask is one byte
                               (LPVOID)NULL,              //No response expected
                               (DWORD) 0,                 //...
                               &BytesReturned,            //Not used but required
                                NULL);                    //Synchronous Operations
      CloseHandle (hDevice);
      exit(1);
    }    
                              

    //Move x & y axes 10 times...                          
    for (i=0; i<10; i++)
    {
      //Make sure the driver's copy of x & y done flags are clear                          
      DoneMask = 0x03;
      Status = DeviceIoControl(
                               hDevice,
                               (DWORD)IOCTL_OMS_CLR_DONE, //Clear selected done flags
                               &DoneMask,                 //Flags selected by ones
                               (DWORD) 1,                 //Mask is one byte
                               (LPVOID)NULL,              //No response expected
                               (DWORD) 0,                 //...
                               &BytesReturned,            //Not used but required
                                NULL);                    //Synchronous Operations
                              
      //Send a move command:
      Status = DeviceIoControl(
                               hDevice,
                               (DWORD)IOCTL_OMS_COMMAND, //Send commmand string
                                                         //don't expect a response
                               "am mr100,200;gd id",  //Command string
                               (DWORD)128,               //Max length of string
                               &CommandCharsSent,  //Returns cmd length
                               (DWORD)1,                  //...
                               &BytesReturned,          
                                NULL);                   //Synchronous Operations
                              
      if(CommandCharsSent != 18)
      {
         printf("Task 1 am mr100... timed out\n");
         CloseHandle (hDevice);
         exit(1);
      }   
                                
      //Wait until the x & y moves are complete
      DoneFlags = 0;
      while ((DoneFlags & 0x03) != 0x03)
      {                          
        Status = DeviceIoControl(
                               hDevice,
                               (DWORD)IOCTL_OMS_READ_DONE,//Read the driver's 
                                                          //copy of the done flags
                               (LPVOID)NULL,              //Command string 
                               (DWORD) 0,                 //not sent
                               &DoneFlags,                //Done flags go here
                               (DWORD)1,                  //Flags require one byte
                               &BytesReturned,            //Bytes returned
                                NULL);                    //Synchronous Operations
      }                          
    
      //Clear z & t bits in the drivers copy of the done flags                          
      DoneMask = 0x03;
      Status = DeviceIoControl(
                               hDevice,
                               (DWORD)IOCTL_OMS_CLR_DONE, //Clear selected done flags
                               &DoneMask,                 //Flags selected by ones
                               (DWORD) 1,                 //Mask is one byte
                               (LPVOID)NULL,              //No response expected
                               (DWORD) 0,                 //...
                               &BytesReturned,            //Not used but required
                                NULL);                    //Synchronous Operations
                                
      //Get the current position of all axes
      //Send the command string "AA RP" to oms1 and wait for the response
      Status = DeviceIoControl(
                               hDevice,               //CreateFile Device handle
                               (DWORD)IOCTL_OMS_QUERY,//Send command get response
                               "am rp;",              //Command string to send
                               (DWORD)128,            //Maximum length of command
                               (LPVOID)ResponseString,//Controller response here
                               (DWORD)128,            //Maximum length response
                               &BytesReturned,        //Actual length of response
                                                      //including the null.
                                NULL);                //Synchronous Operations 
      if(ResponseString[0] != (UCHAR)NULL)
      {
        printf("%d - Axes positions = %s \n", (i+1), ResponseString);
      }
      else
      {
        printf("***Task 1 response time out \n");
        Status = DeviceIoControl(
                               hDevice,
                               (DWORD)IOCTL_OMS_READ_STATUS,//Read the driver's 
                                                          //copy of the status flags
                               (LPVOID)NULL,              //Command string 
                               (DWORD) 0,                 //not sent
                               &StatusFlags,              //Status flags go here
                               (DWORD)1,                  //Flags require one byte
                               &BytesReturned,            //Bytes returned
                                NULL);                    //Synchronous Operations
        //Make sure the driver's copy of status flags are clear                          
        StatusMask = 0xff;
        Status = DeviceIoControl(
                                 hDevice,
                                 (DWORD)IOCTL_OMS_CLR_STATUS, //Clear selected done flags
                                 &StatusMask,                 //Flags selected by ones
                                 (DWORD) 1,                 //Mask is one byte
                                 (LPVOID)NULL,              //No response expected
                                 (DWORD) 0,                 //...
                                 &BytesReturned,            //Not used but required
                                  NULL);                    //Synchronous Operations
        printf("Task 1 status flags = %0x \n", StatusFlags);                        
        CloseHandle (hDevice);
        exit(1);
      }    
                              
    }
    Status = DeviceIoControl(
                             hDevice,               //CreateFile Device handle
                             (DWORD)IOCTL_OMS_QUERY,//Send command get response
                             "am rp;",              //Command string to send
                             (DWORD)128,            //Maximum length of command
                             (LPVOID)ResponseString,//Controller response here
                             (DWORD)128,            //Maximum length response
                             &BytesReturned,        //Actual length of response
                                                    //including the null.
                              NULL);                //Synchronous Operations 
    printf(" Axes positions before reset = %s \n", ResponseString);

   //Send reset to controller and reinitialize driver variables
   Status =  DeviceIoControl(hDevice, 
                             (DWORD)IOCTL_OMS_RESET,
                             (LPVOID)NULL,
                             0,
                             &ResetOk,
                             1,
                             &BytesReturned,
                             NULL
                            );
   if(ResetOk)
      printf("Reset was successful\n");
    Status = DeviceIoControl(
                             hDevice,               //CreateFile Device handle
                             (DWORD)IOCTL_OMS_QUERY,//Send command get response
                             "am rp;",              //Command string to send
                             (DWORD)128,            //Maximum length of command
                             (LPVOID)ResponseString,//Controller response here
                             (DWORD)128,            //Maximum length response
                             &BytesReturned,        //Actual length of response
                                                    //including the null.
                              NULL);                //Synchronous Operations 
    printf(" Axes positions after reset = %s \n", ResponseString);

    //Get the driver's version
    Status = DeviceIoControl(
                             hDevice,               //CreateFile Device handle
                             (DWORD)IOCTL_OMS_GET_VERSION,
                             (LPVOID)NULL,      //Command string to send
                             (DWORD)0,            //Maximum length of command
                             (LPVOID)ResponseString,//Controller response here
                             (DWORD)128,            //Maximum length response
                             &BytesReturned,        //Actual length of response
                                                    //including the null.
                              NULL);                //Synchronous Operations 
    if(ResponseString[0] != (UCHAR)NULL)
    {
      printf("Driver Version = %s \n", ResponseString);
    }
    
    //Close the motor controller's device handle
    CloseHandle (hDevice);
}

