//Oregon Micro Systems Motor Control DLL definitions:
//This header file is for the DLL that works with the Windows NT PC3X
//driver.  The function prototypes are to be used with "C" applications
// and are for the standard long integer version of the DLL.
//
//  MODULE:   nt3xli.h
//
//


#ifndef INC_OMSDLL_H
#define INC_OMSDLL_H

#include <windows.h>

//Function error code definitions
#define SUCCESS                0
#define COMMAND_TIME_OUT       1
#define RESPONSE_TIME_OUT      2
#define INVALID_AXIS_SELECTION 3
#define MOVE_TIME_OUT          4
#define INVALID_PARAMETER      5
#define INVALID_BIT_NUMBER     6

//Controller status defintions
#define COMMAND_ERROR           0x01
#define CONTROLLER_INITIALIZING 0x02
#define ENCODER_SLIP            0x04
#define OVERTRAVEL_ERROR        0x08

//Axis status definitions
#define DIRECTION   0x01
#define DONE        0x02
#define OVERTRAVEL  0x04
#define HOME_SWITCH 0x08

//Encoder status definitions
#define SLIP_DETECT_ENABLED 0x01
#define POSITION_MAINTENANCE_ENABLED 0x02
#define AXIS_SLIPPED 0x04
#define AXIS_WITHIN_DEADBAND 0x08
#define ENCODER_AT_HOME 0x10

//Function arguments
#define POSITIVE    0
#define NEGATIVE    1
#define MODE_OFF 0
#define MODE_ON 1
#define LOW 0
#define HIGH 1

//Axis selection codes
#define OMS_X_AXIS 0x01
#define OMS_Y_AXIS 0x02
#define OMS_Z_AXIS 0x04
#define OMS_T_AXIS 0x08
#define OMS_U_AXIS 0x10
#define OMS_V_AXIS 0x20
#define OMS_R_AXIS 0x40
#define OMS_S_AXIS 0x80
#define OMS_ALL_4  0x0f
#define OMS_ALL_6  0x3f
#define OMS_ALL_8  0xff

//I/O bit selection codes
#define BIT0  0x01
#define BIT1  0x02
#define BIT2  0x04
#define BIT3  0x08
#define BIT4  0x10
#define BIT5  0x20
#define BIT6  0x40
#define BIT7  0x80
#define BIT8  0x100
#define BIT9  0x200
#define BIT10 0x400
#define BIT11 0x800
#define BIT12 0x1000
#define BIT13 0x2000

//Absolute position limits for controller
#define MIN_POSITION -67108863
#define MAX_POSITION  67108863

#define MIN_VELOCITY 1
#define MAX_VELOCTIY 522000

#define MIN_ACCELERATION 1
#define MAX_ACCELERATION 2000000

typedef struct
{
  long X;
  long Y;
  long Z;
  long T;
  long U;
  long V;
  long R;
  long S;
}AXES_DATA, *PAXES_DATA;

//Function prototypes
HANDLE _stdcall GetOmsHandle( LPSTR );
void _stdcall CloseOmsHandle( HANDLE);
int _stdcall ResetOmsController(HANDLE);
int _stdcall SendOmsQueryCommand(HANDLE, LPSTR, LPSTR);
int _stdcall SendOmsTextCommand(HANDLE, LPSTR);
int _stdcall GetAllOmsDoneFlags(HANDLE, int *);
int _stdcall GetAllOmsSlipFlags(HANDLE, int *);
int _stdcall GetOmsAxisDoneFlag(HANDLE, int , BOOL*);
int _stdcall GetOmsAxisFlags(HANDLE, int , int*);
int _stdcall GetOmsEncoderFlags(HANDLE, int , int*);
int _stdcall GetOmsControllerDescription(HANDLE, LPSTR);
int _stdcall GetOmsControllerFlags(HANDLE, int *);
int _stdcall ClrOmsDoneFlags(HANDLE, int);
int _stdcall ClrOmsControllerFlags(HANDLE, int);
int _stdcall SetOmsAxisPosition(HANDLE, int , long);
int _stdcall SetOmsAxisAcceleration(HANDLE, int , long);
int _stdcall SetOmsAxisVelocity(HANDLE, int , long);
int _stdcall SetOmsAxisBaseVelocity(HANDLE, int , long);
int _stdcall SelectOmsLinearRamp(HANDLE);
int _stdcall SelectOmsCosineRamp(HANDLE);
int _stdcall SelectOmsParabolicRamp(HANDLE, int);
int _stdcall GetOmsAxisMotorPosition(HANDLE, int , long *);
int _stdcall GetSelectedOmsMotorPositions(HANDLE, int, PAXES_DATA);
int _stdcall GetOmsAxisEncoderPosition(HANDLE, int , long *);
int _stdcall GetOmsAxisAcceleration(HANDLE, int , long *);
int _stdcall GetSelectedOmsAccelerations(HANDLE, int, PAXES_DATA);
int _stdcall GetOmsAxisVelocity(HANDLE, int , long *);
int _stdcall GetSelectedOmsVelocities(HANDLE, int, PAXES_DATA);
int _stdcall StopOmsAxis(HANDLE, int );
int _stdcall StopAllOmsAxes(HANDLE );
int _stdcall KillAllOmsMotion(HANDLE);
int _stdcall MoveOmsAxisIndefinite(HANDLE, int , long );
int _stdcall MoveOmsAxisFractional(HANDLE, int , double );
int _stdcall MoveOmsAxisAbsWait(HANDLE, int , long, long );
int _stdcall MoveOmsAxisAbs(HANDLE, int , long);
int _stdcall MoveOmsAxisRelWait(HANDLE, int , long, long );
int _stdcall MoveOmsAxisRel(HANDLE, int , long);
int _stdcall MoveOmsIndependantAbs(HANDLE, int , PAXES_DATA);
int _stdcall MoveOmsIndependantAbsWait(HANDLE, int , PAXES_DATA, long);
int _stdcall MoveOmsIndependantRel(HANDLE, int , PAXES_DATA);
int _stdcall MoveOmsIndependantRelWait(HANDLE, int , PAXES_DATA, long);
int _stdcall MoveOmsIndependantAbsMt(HANDLE, int , PAXES_DATA);
int _stdcall MoveOmsIndependantAbsMtWait(HANDLE, int , PAXES_DATA, long);
int _stdcall MoveOmsIndependantRelMt(HANDLE, int , PAXES_DATA);
int _stdcall MoveOmsIndependantRelMtWait(HANDLE, int , PAXES_DATA, long);
int _stdcall MoveOmsLinearAbs(HANDLE, int , PAXES_DATA);
int _stdcall MoveOmsLinearAbsWait(HANDLE, int , PAXES_DATA, long);
int _stdcall MoveOmsLinearRel(HANDLE, int , PAXES_DATA);
int _stdcall MoveOmsLinearRelWait(HANDLE, int , PAXES_DATA, long);
int _stdcall MoveOmsLinearAbsMt(HANDLE, int , PAXES_DATA);
int _stdcall MoveOmsLinearAbsMtWait(HANDLE, int , PAXES_DATA, long);
int _stdcall MoveOmsLinearRelMt(HANDLE, int , PAXES_DATA);
int _stdcall MoveOmsLinearRelMtWait(HANDLE, int , PAXES_DATA, long);
int _stdcall HomeOmsAxisFwdUseEncoder(HANDLE , int, long);
int _stdcall HomeOmsAxisFwdUseEncoderWait(HANDLE, int, long, long);
int _stdcall HomeOmsAxisRevUseEncoder(HANDLE, int, long);
int _stdcall HomeOmsAxisRevUseEncoderWait(HANDLE, int, long, long);
int _stdcall HomeOmsAxisFwdUseSwitch(HANDLE , int, long);
int _stdcall HomeOmsAxisFwdUseSwitchWait(HANDLE, int, long, long);
int _stdcall HomeOmsAxisRevUseSwitch(HANDLE, int, long);
int _stdcall HomeOmsAxisRevUseSwitchWait(HANDLE, int, long, long);
int _stdcall DefineOmsHomeAsSwitchClosed(HANDLE, int);
int _stdcall DefineOmsHomeAsSwitchOpen(HANDLE, int);
int _stdcall MoveOmsAxisOneStep(HANDLE, int , int );
int _stdcall FindOmsAxisFwdLimit(HANDLE, int, long, long);
int _stdcall FindOmsAxisRevLimit(HANDLE, int, long, long);
int _stdcall SetOmsEncoderRatio(HANDLE, int, int, int);
int _stdcall SetOmsEncoderSlipTolerance(HANDLE, int, int);
int _stdcall EnableOmsSlipDetection(HANDLE, int);
int _stdcall SetOmsEncoderHoldMode(HANDLE, int, int);
int _stdcall SetOmsHoldDeadBand(HANDLE, int, int);
int _stdcall SetOmsHoldGain(HANDLE, int, int);
int _stdcall SetOmsHoldVelocity(HANDLE, int, long);
int _stdcall SetOmsAxisOvertravelDetect(HANDLE, int, int);
int _stdcall SetOmsSoftLimitsMode(HANDLE, int);
int _stdcall GetOmsIOBit(HANDLE, int, BOOL *);
int _stdcall GetAllOmsIOBits(HANDLE, int *);
int _stdcall GetOmsIOBitConfig(HANDLE, int *);
int _stdcall SetOmsIOBit(HANDLE, int, BOOL);
int _stdcall SetOmsAxisAuxOutBit(HANDLE, int, BOOL);
int _stdcall SetSelectedOmsAuxOutBits(HANDLE, int, BOOL);
int _stdcall SetOmsAxisAuxOutSettleTime(HANDLE, int, int);
int _stdcall EnableOmsAxisAuxOutAutoMode(HANDLE, int, BOOL);
int _stdcall OmsWait(int);
int _stdcall SoftIceBreak(void);


#endif  // INC_OMSDLL_H
  
