Attribute VB_Name = "OMS"

'Reserve a global device handle
Public OmsHandle As Long

'DLL function status code definitions
Public Const SUCCESS As Long = 0
Public Const COMMAND_TIME_OUT As Long = 1
Public Const RESPONSE_TIME_OUT As Long = 2
Public Const INVALID_AXIS_SELECTION As Long = 3
Public Const MOVE_TIME_OUT As Long = 4
Public Const INVALID_PARAMETER As Long = 5
Public Const INVALID_BIT_NUMBER As Long = 6

'Controller Status Flag Definitions
Public Const COMMAND_ERROR As Long = 1
Public Const ENCODER_SLIP As Long = 4
Public Const OVERTRAVEL_ERROR As Long = 8

'Axis Status Flag Definitions
Public Const DIRECTION As Long = 1
Public Const DONE As Long = 2
Public Const OVERTRAVEL As Long = 4
Public Const HOME_SWITCH As Long = 8

'Encoder Status Flag Definitions
Public Const SLIP_DETECT_ENABLED As Long = 1
Public Const POSITION_MAINTENANCE_ENABLED As Long = 2
Public Const AXIS_SLIPPED As Long = 4
Public Const AXIS_WITHIN_DEADBAND As Long = 8
Public Const ENCODER_AT_HOME As Long = 16

'Mode selection parameters
Public Const MODE_OFF As Long = 0
Public Const MODE_ON  As Long = 1

'One step move directions
Public Const POSITIVE As Long = 0
Public Const NEGATIVE As Long = 1

'Axis selection codes
Public Const OMS_X_AXIS As Long = 1
Public Const OMS_Y_AXIS As Long = 2
Public Const OMS_Z_AXIS As Long = 4
Public Const OMS_T_AXIS As Long = 8
Public Const OMS_U_AXIS As Long = 16
Public Const OMS_V_AXIS As Long = 32
Public Const OMS_R_AXIS As Long = 64
Public Const OMS_S_AXIS As Long = 128

'I/O bit selection codes
Public Const BIT0  As Long = 1
Public Const BIT1  As Long = 2
Public Const BIT2  As Long = 4
Public Const BIT3  As Long = 8
Public Const BIT4  As Long = 16
Public Const BIT5  As Long = 32
Public Const BIT6  As Long = 64
Public Const BIT7  As Long = 128
Public Const BIT8  As Long = 256
Public Const BIT9  As Long = 512
Public Const BIT10 As Long = 1024
Public Const BIT11 As Long = 2048
Public Const BIT12 As Long = 4096
Public Const BIT13 As Long = 8192

'Define a structure to pass data for multiple axes to/from functions
Public Type AXES_DATA
  X As Long
  Y As Long
  Z As Long
  T As Long
  U As Long
  V As Long
  R As Long
  S As Long
End Type
  
'DLL function declarations
Declare Sub CloseOmsHandle Lib "nt3xli" _
        (ByVal DeviceHandle As Long)
Declare Function ClrOmsControllerFlags Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal FlagMask As Long) As Long
Declare Function ClrOmsDoneFlags Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal FlagMask As Long) As Long
Declare Function DefineOmsHomeAsSwitchClosed Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long) As Long
Declare Function DefineOmsHomeAsSwitchOpen Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long) As Long
Declare Function EnableOmsAxisAuxOutAutoMode Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal MotionState As Boolean) As Long
Declare Function EnableOmsSlipDetection Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long) As Long
Declare Function FindOmsAxisFwdLimit Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Velocity As Long, _
         ByVal TimeLimit As Long) As Long
Declare Function FindOmsAxisRevLimit Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Velocity As Long, _
         ByVal TimeLimit As Long) As Long
Declare Function GetAllOmsDoneFlags Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByRef DoneFlags As Long) As Long
Declare Function GetAllOmsIOBits Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByRef BitStates As Long) As Long
Declare Function GetAllOmsSlipFlags Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByRef FlagStatus As Long) As Long
Declare Function GetOmsAxisDoneFlag Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef FlagStatus As Boolean) As Long
Declare Function GetOmsAxisFlags Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef FlagStatus As Long) As Long
Declare Function GetOmsControllerDescription Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal Description As String) As Long
Declare Function GetOmsControllerFlags Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByRef Flags As Long) As Long
Declare Function GetOmsEncoderFlags Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef FlagStatus As Long) As Long
Declare Function GetOmsHandle Lib "nt3xli" _
        (ByVal DeviceName As String) As Long
Declare Function GetOmsAxisAcceleration Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Acceleration As Long) As Long
Declare Function GetOmsAxisEncoderPosition Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Position As Long) As Long
Declare Function GetOmsAxisMotorPosition Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Position As Long) As Long
Declare Function GetOmsAxisVelocity Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Velocity As Long) As Long
Declare Function GetOmsIOBit Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal BitNumber As Long, _
         ByRef BitState As Boolean) As Long
Declare Function GetOmsIOBitConfig Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByRef BitConfig As Long) As Long
Declare Function GetSelectedOmsAccelerations Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Accelerations As AXES_DATA) As Long
Declare Function GetSelectedOmsMotorPositions Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA) As Long
Declare Function GetSelectedOmsVelocities Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Velocities As AXES_DATA) As Long
Declare Function HomeOmsAxisFwdUseEncoder Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Position As Long) As Long
Declare Function HomeOmsAxisFwdUseEncoderWait Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Position As Long, _
         ByVal TimeLimit As Long) As Long
Declare Function HomeOmsAxisFwdUseSwitch Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Position As Long) As Long
Declare Function HomeOmsAxisFwdUseSwitchWait Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Position As Long, _
         ByVal TimeLimit As Long) As Long
Declare Function HomeOmsAxisRevUseEncoder Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Position As Long) As Long
Declare Function HomeOmsAxisRevUseEncoderWait Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Position As Long, _
         ByVal TimeLimit As Long) As Long
Declare Function HomeOmsAxisRevUseSwitch Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Position As Long) As Long
Declare Function HomeOmsAxisRevUseSwitchWait Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Position As Long, _
         ByVal TimeLimit As Long) As Long
Declare Function KillAllOmsMotion Lib "nt3xli" _
        (ByVal DeviceHandle As Long) As Long
Declare Function MoveOmsAxisAbs Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Position As Long) As Long
Declare Function MoveOmsAxisAbsWait Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Position As Long, _
         ByVal TimeLimit As Long) As Long
Declare Function MoveOmsAxisFractional Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Velocity As Double) As Long
Declare Function MoveOmsAxisIndefinite Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Velocity As Long) As Long
Declare Function MoveOmsAxisOneStep Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Direction As Long) As Long
Declare Function MoveOmsAxisRel Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Position As Long) As Long
Declare Function MoveOmsAxisRelWait Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Position As Long, _
         ByVal TimeLimit As Long) As Long
Declare Function MoveOmsIndependantAbs Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA) As Long
Declare Function MoveOmsIndependantAbsMt Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA) As Long
Declare Function MoveOmsIndependantAbsMtWait Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA, _
         ByVal TimeLimit As Long) As Long
Declare Function MoveOmsIndependantAbsWait Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA, _
         ByVal TimeLimit As Long) As Long
Declare Function MoveOmsIndependantRel Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA) As Long
Declare Function MoveOmsIndependantRelMt Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA) As Long
Declare Function MoveOmsIndependantRelMtWait Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA, _
         ByVal TimeLimit As Long) As Long
Declare Function MoveOmsIndependantRelWait Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA, _
         ByVal TimeLimit As Long) As Long
Declare Function MoveOmsLinearAbs Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA) As Long
Declare Function MoveOmsLinearAbsMt Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA) As Long
Declare Function MoveOmsLinearAbsMtWait Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA, _
         ByVal TimeLimit As Long) As Long
Declare Function MoveOmsLinearAbsWait Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA, _
         ByVal TimeLimit As Long) As Long
Declare Function MoveOmsLinearRel Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA) As Long
Declare Function MoveOmsLinearRelMt Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA) As Long
Declare Function MoveOmsLinearRelMtWait Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA, _
         ByVal TimeLimit As Long) As Long
Declare Function MoveOmsLinearRelWait Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByRef Positions As AXES_DATA, _
         ByVal TimeLimit As Long) As Long
Declare Function OmsWait Lib "nt3xli" _
        (ByVal WaitTime As Long) As Long
Declare Function ResetOmsController Lib "nt3xli" _
        (ByVal DeviceHandle As Long) As Long
Declare Function SelectOmsCosineRamp Lib "nt3xli" _
        (ByVal DeviceHandle As Long) As Long
Declare Function SelectOmsLinearRamp Lib "nt3xli" _
        (ByVal DeviceHandle As Long) As Long
Declare Function SelectOmsParabolicRamp Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal Steps As Long) As Long
Declare Function SendOmsQueryCommand Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal Command As String, _
         ByVal Response As String) As Long
Declare Function SendOmsTextCommand Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal Command As String) As Long
Declare Function SetOmsAxisAcceleration Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal AxisAccel As Long) As Long
Declare Function SetOmsAxisAuxOutBit Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal BitState As Boolean) As Long
Declare Function SetOmsAxisAuxOutSettleTime Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal SettleTime As Long) As Long
Declare Function SetOmsAxisBaseVelocity Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal AxisBaseVelocity As Long) As Long
Declare Function SetOmsAxisOvertravelDetect Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal LimitMode As Long) As Long
Declare Function SetOmsAxisPosition Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal AxisPosition As Long) As Long
Declare Function SetOmsAxisVelocity Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal Velocity As Long) As Long
Declare Function SetOmsEncoderHoldMode Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal HoldMode As Long) As Long
Declare Function SetOmsEncoderRatio Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal EncoderCount As Long, _
         ByVal MotorCount As Long) As Long
Declare Function SetOmsEncoderSlipTolerance Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal SlipTol As Long) As Long
Declare Function SetOmsHoldDeadBand Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal DeadBand As Long) As Long
Declare Function SetOmsHoldGain Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal HoldGain As Long) As Long
Declare Function SetOmsHoldVelocity Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal HoldVelocity As Long) As Long
Declare Function SetOmsIOBit Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal BitNumber As Long, _
         ByVal BitState As Boolean) As Long
Declare Function SetOmsSoftLimitsMode Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal SoftLimit As Long) As Long
Declare Function SetSelectedOmsAuxOutBits Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long, _
         ByVal BitState As Boolean) As Long
Declare Function StopAllOmsAxes Lib "nt3xli" _
        (ByVal DeviceHandle As Long) As Long
Declare Function StopOmsAxis Lib "nt3xli" _
        (ByVal DeviceHandle As Long, _
         ByVal AxisSelection As Long) As Long


